#!/bin/sh
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2011, 2012 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

DIRHOME=
DBPROPFILENAME=
JAVAPATH=
VALIDDIRVERSION1=6.3
VALIDDIRVERSION2=6.3.0
TPCHOME=/opt/IBM/TPC

if [ ! -f $TPCHOME/version.txt ] ; then
   exit 0;
fi


function displayMessage
{
   if [ "$JAVAPATH" != "" ]; then
     "$JAVAPATH/java" -cp $CLASSPATH DisplayMessage $*
   fi
}

#Check if Director is installed
function CheckDirectorLinux
{
   if [ "$SC_DEBUG" != "" ] ; then
      DIRHOME=$SC_DEBUG
      DBPROPFILENAME=$DIRHOME/lwi/conf/overrides/database.properties
      JAVAPATH=$DIRHOME/jre/bin
      CLASSPATH=$DIRHOME/lwi/lib/passutils.jar:$DIRHOME/lwi/lib/lwisecurity.jar:$DIRHOME/StorageControl/lib/*:$TPCHOME/uninstallFiles/install/ep_common.jar
      return 0
   fi
   rpm -qa ISDServer >/dev/null 2>&1
   if [ $? -ne 0 ] ; then
     return 1
   fi
   
   if [ -f /etc/ibm/director/twgserver/twgserver ] ; then
     DIRHOME=$(cat /etc/ibm/director/twgserver/twgserver|grep SERVER_HOME|awk -F"=" '{print $2}')
   else
      return 1
   fi
   VERSIONFILE=$DIRHOME/version.srv
   if [ -f $VERSIONFILE ] ; then
      VERSION=$(grep version= $DIRHOME/version.srv  | awk -F '=' '{print $2}')
      if [ "$VERSION" \< "$VALIDDIRVERSION1" ] ; then
         if [ "$VERSION" \< "$VALIDDIRVERSION2" ] ; then
           return 1
        fi
      fi
   else
      return 1
   fi
   DBPROPFILENAME=$DIRHOME/lwi/conf/overrides/database.properties
   JAVAPATH=$DIRHOME/jre/bin
   CLASSPATH=$DIRHOME/lwi/lib/passutils.jar:$DIRHOME/lwi/lib/lwisecurity.jar:$DIRHOME/StorageControl/lib/*:$TPCHOME/uninstallFiles/install/ep_common.jar
   return 0
}

function CheckDirectorAIX
{
   if [ "$SC_DEBUG" != "" ] ; then
      DIRHOME=$SC_DEBUG
      DBPROPFILENAME=$DIRHOME/lwi/conf/overrides/database.properties
      JAVAPATH=$DIRHOME/jre/bin
      CLASSPATH=$DIRHOME/lwi/lib/passutils.jar:$DIRHOME/lwi/lib/lwisecurity.jar:$DIRHOME/StorageControl/lib/*:$TPCHOME/uninstallFiles/install/ep_common.jar
      return 0
   fi
   lslpp -l "DirectorServer" >/dev/null 2>&1
   if [ $? -ne 0 ] ; then
     return 1
   fi

   if [ -f /etc/ibm/director/twgserver/twgserver ] ; then
     DIRHOME=$(cat /etc/ibm/director/twgserver/twgserver|grep TWG_ROOTDIR|awk -F"=" '{print $2}')
   else
      return 1
   fi
   VERSIONFILE=$DIRHOME/version.srv
   if [ -f $VERSIONFILE ] ; then
      VERSION=$(grep version= $DIRHOME/version.srv  | awk -F '=' '{print $2}')
      if [[ "$VERSION" < "$VALIDDIRVERSION1" ]] ; then
         if [[ "$VERSION" < "$VALIDDIRVERSION2" ]] ; then
           return 1
        fi
      fi
   else
      return 1
   fi
   DBPROPFILENAME=$DIRHOME/lwi/conf/overrides/database.properties
   JAVAPATH=$DIRHOME/jre/bin
   CLASSPATH=$DIRHOME/lwi/lib/passutils.jar:$DIRHOME/lwi/lib/lwisecurity.jar:$DIRHOME/StorageControl/lib/*:$TPCHOME/uninstallFiles/install/ep_common.jar
   return 0
}

function checkIfDB2
{
   if [ "$DIRHOME" != "" ] ; then
      DBFILENAME=$DIRHOME/lwi/conf/overrides/database.properties
      if [ -f $DBFILENAME ] ; then
         DB2DB=$(grep rcs.dbprovider $DIRHOME/lwi/conf/overrides/database.properties  | awk '{print $3}')
         FOUNDDB2=$(echo $DB2DB | grep DB2Provider)
      if [ $? != 0 ] ; then
         return 1;
      fi
   fi
  else
     return 1;
  fi
  return 0;
}

USER=`id -u`

if [ $USER -ne 0 ] ; then
   displayMessage "ADMIN_ACCESS_REQUIRED"
   exit -7
fi

OS=$(uname)
if [ "$OS" == "Linux" ]; then
   CheckDirectorLinux
else
#  Assume it is AIX
   CheckDirectorAIX
fi

if [ $? -ne 0 ] ; then
   displayMessage "ISD_NOT_INSTALLED"
   exit -3
fi

checkIfDB2

if [ $? -ne 0 ] ; then
   displayMessage "DB2_NOT_FOUND"
   exit -4
fi

